"use strict";

exports.__esModule = true;
exports["default"] = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _helper = require("./Shared/helper.js");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

//component - CoreUI / CButton
var CButton = function CButton(props) {
  var Tag = props.tag,
      children = props.children,
      className = props.className,
      cssModule = props.cssModule,
      innerRef = props.innerRef,
      active = props.active,
      ariaLabel = props['aria-label'],
      block = props.block,
      close = props.close,
      color = props.color,
      size = props.size,
      textHtml = props.textHtml,
      pressed = props.pressed,
      shape = props.shape,
      variant = props.variant,
      attributes = _objectWithoutPropertiesLoose(props, ["tag", "children", "className", "cssModule", "innerRef", "active", "aria-label", "block", "close", "color", "size", "textHtml", "pressed", "shape", "variant"]);

  var onClick = function onClick(e) {
    if (props.disabled) {
      e.preventDefault();
      return;
    }

    if (props.onClick) {
      props.onClick(e);
    }
  }; //render


  if (close && typeof children === 'undefined') {
    children = _react["default"].createElement("span", {
      "aria-hidden": true
    }, "\xD7");
  }

  var btnColor = "btn" + (variant ? '-' + variant : '') + "-" + color;
  var classes = (0, _helper.mapToCssModules)((0, _classnames["default"])(className, {
    close: close
  }, close || 'btn', close || btnColor, size ? "btn-" + size : false, block ? 'btn-block' : false, shape ? "btn-" + shape : false, pressed ? 'btn-pressed' : false, {
    'active': active,
    'disabled': props.disabled
  }), cssModule);

  if (attributes.href && Tag === 'button') {
    Tag = 'a';
  }

  var defaultAriaLabel = close ? 'Close' : null;
  return _react["default"].createElement(Tag, _extends({
    type: Tag === 'button' && attributes.onClick ? 'button' : undefined
  }, attributes, {
    className: classes,
    onClick: onClick,
    "aria-label": ariaLabel || defaultAriaLabel,
    ref: innerRef
  }), textHtml ? textHtml : children);
};

CButton.propTypes = process.env.NODE_ENV !== "production" ? {
  tag: _helper.tagPropType,
  children: _propTypes["default"].node,
  cssModule: _propTypes["default"].object,
  className: _propTypes["default"].string,
  //
  innerRef: _propTypes["default"].oneOfType([_propTypes["default"].object, _propTypes["default"].func, _propTypes["default"].string]),
  active: _propTypes["default"].bool,
  block: _propTypes["default"].bool,
  shape: _propTypes["default"].string,
  variant: _propTypes["default"].oneOf(['', 'ghost', 'outline']),
  color: _propTypes["default"].string,
  close: _propTypes["default"].bool,
  disabled: _propTypes["default"].bool,
  onClick: _propTypes["default"].func,
  size: _propTypes["default"].string,
  pressed: _propTypes["default"].bool,
  textHtml: _propTypes["default"].string,
  'aria-label': _propTypes["default"].string
} : {};
CButton.defaultProps = {
  tag: 'button'
}; //export

var _default = CButton;
exports["default"] = _default;
module.exports = exports.default;