"use strict";

exports.__esModule = true;
exports["default"] = exports.Context = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _helper = require("./Shared/helper.js");

var _CPaginationItem = _interopRequireDefault(require("./CPaginationItem"));

var _CPaginationLink = _interopRequireDefault(require("./CPaginationLink"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var Context = _react["default"].createContext({}); //component - CoreUI / CPagination


exports.Context = Context;

var CPagination = function CPagination(props) {
  var _classNames;

  var Tag = props.tag,
      children = props.children,
      className = props.className,
      cssModule = props.cssModule,
      custom = props.custom,
      innerRef = props.innerRef,
      listClassName = props.listClassName,
      pageFrom = props.pageFrom,
      pageTo = props.pageTo,
      pageMin = props.pageMin,
      pageMax = props.pageMax,
      activePage = props.activePage,
      size = props.size,
      firstButtonHtml = props.firstButtonHtml,
      previousButtonHtml = props.previousButtonHtml,
      nextButtonHtml = props.nextButtonHtml,
      lastButtonHtml = props.lastButtonHtml,
      hideDots = props.hideDots,
      ListTag = props.listTag,
      label = props['aria-label'],
      listProps = props.listProps,
      onClick = props.onClick,
      attributes = _objectWithoutPropertiesLoose(props, ["tag", "children", "className", "cssModule", "custom", "innerRef", "listClassName", "pageFrom", "pageTo", "pageMin", "pageMax", "activePage", "size", "firstButtonHtml", "previousButtonHtml", "nextButtonHtml", "lastButtonHtml", "hideDots", "listTag", "aria-label", "listProps", "onClick"]);

  var paginationClick = function paginationClick(e, type, n) {
    onClick && onClick(e, type, n);
  }; //render


  var classes = (0, _helper.mapToCssModules)((0, _classnames["default"])(className), cssModule);
  var listClasses = (0, _helper.mapToCssModules)((0, _classnames["default"])(listClassName, 'pagination', (_classNames = {}, _classNames["pagination-" + size] = !!size, _classNames)), cssModule);
  var autoChildren;

  if (!custom) {
    var list = [];

    for (var _i = pageFrom; _i <= pageTo; _i++) {
      list.push(_react["default"].createElement(_CPaginationItem["default"], {
        custom: true,
        key: _i,
        active: activePage == _i ? true : false
      }, _react["default"].createElement(_CPaginationLink["default"], {
        type: "number",
        n: _i
      }, _i)));
    }

    var pagesBefore = pageFrom > pageMin;
    var pagesAfter = pageTo < pageMax;
    autoChildren = _react["default"].createElement(_react["default"].Fragment, null, pagesBefore && firstButtonHtml ? _react["default"].createElement(_CPaginationItem["default"], {
      custom: true
    }, _react["default"].createElement(_CPaginationLink["default"], {
      type: "first"
    }, firstButtonHtml)) : '', pagesBefore && previousButtonHtml ? _react["default"].createElement(_CPaginationItem["default"], {
      custom: true
    }, _react["default"].createElement(_CPaginationLink["default"], {
      type: "previous"
    }, previousButtonHtml)) : '', !hideDots && pagesBefore ? _react["default"].createElement(_CPaginationItem["default"], {
      custom: true
    }, _react["default"].createElement(_CPaginationLink["default"], {
      type: "less"
    }, "...")) : '', list, !hideDots && pagesAfter ? _react["default"].createElement(_CPaginationItem["default"], {
      custom: true
    }, _react["default"].createElement(_CPaginationLink["default"], {
      type: "more"
    }, "...")) : '', pagesAfter && nextButtonHtml ? _react["default"].createElement(_CPaginationItem["default"], {
      custom: true
    }, _react["default"].createElement(_CPaginationLink["default"], {
      type: "next"
    }, nextButtonHtml)) : '', pagesAfter && lastButtonHtml ? _react["default"].createElement(_CPaginationItem["default"], {
      custom: true
    }, _react["default"].createElement(_CPaginationLink["default"], {
      type: "last"
    }, lastButtonHtml)) : '');
  }

  return _react["default"].createElement(Context.Provider, {
    value: {
      paginationClick: paginationClick
    }
  }, _react["default"].createElement(Tag, _extends({}, attributes, {
    className: classes,
    "aria-label": label,
    ref: innerRef
  }), _react["default"].createElement(ListTag, _extends({
    className: listClasses
  }, listProps), autoChildren || children)));
};

CPagination.propTypes = process.env.NODE_ENV !== "production" ? {
  tag: _helper.tagPropType,
  children: _propTypes["default"].node,
  className: _propTypes["default"].string,
  cssModule: _propTypes["default"].object,
  custom: _propTypes["default"].bool,
  //
  innerRef: _propTypes["default"].oneOfType([_propTypes["default"].object, _propTypes["default"].func, _propTypes["default"].string]),
  pageMin: _propTypes["default"].number,
  pageMax: _propTypes["default"].number,
  pageFrom: _propTypes["default"].number,
  pageTo: _propTypes["default"].number,
  activePage: _propTypes["default"].number,
  size: _propTypes["default"].string,
  listTag: _helper.tagPropType,
  hideDots: _propTypes["default"].bool,
  hideArrows: _propTypes["default"].bool,
  hideDoubleArrows: _propTypes["default"].bool,
  firstButtonHtml: _propTypes["default"].oneOfType([_propTypes["default"].object, _propTypes["default"].string]),
  previousButtonHtml: _propTypes["default"].oneOfType([_propTypes["default"].object, _propTypes["default"].string]),
  nextButtonHtml: _propTypes["default"].oneOfType([_propTypes["default"].object, _propTypes["default"].string]),
  lastButtonHtml: _propTypes["default"].oneOfType([_propTypes["default"].object, _propTypes["default"].string]),
  'aria-label': _propTypes["default"].string,
  listClassName: _propTypes["default"].string,
  listProps: _propTypes["default"].object,
  onClick: _propTypes["default"].func
} : {};
CPagination.defaultProps = {
  tag: 'nav',
  listTag: 'ul',
  'aria-label': 'pagination',
  pageFrom: 2,
  pageTo: 3,
  pageMin: 1,
  pageMax: 5,
  activePage: 2,
  firstButtonHtml: _react["default"].createElement(_react["default"].Fragment, null, "\xAB"),
  previousButtonHtml: _react["default"].createElement(_react["default"].Fragment, null, "\u2039"),
  nextButtonHtml: _react["default"].createElement(_react["default"].Fragment, null, "\u203A"),
  lastButtonHtml: _react["default"].createElement(_react["default"].Fragment, null, "\xBB")
};
var _default = CPagination;
exports["default"] = _default;